Split should have a matching Join, if only for convenient debugging output.

Change-Id: I68275a6410af706875f53540db4ef0242f414470
diff --git a/src/utils.h b/src/utils.h
index 7807299..74a9802 100644
--- a/src/utils.h
+++ b/src/utils.h
@@ -256,9 +256,12 @@
   return ns * 1000 * 1000;
 }
 
 // Splits a string using the given delimiter character into a vector of
 // strings. Empty strings will be omitted.
-void Split(const std::string& s, char delim, std::vector<std::string>& result);
+void Split(const std::string& s, char separator, std::vector<std::string>& result);
+
+// Joins a vector of strings into a single string, using the given separator.
+template <typename StringT> std::string Join(std::vector<StringT>& strings, char separator);
 
 // Returns the calling thread's tid. (The C libraries don't expose this.)
 pid_t GetTid();
@@ -256,9 +256,12 @@
 }
 
-// Splits a string using the given delimiter character into a vector of
+// Splits a string using the given separator character into a vector of
 // strings. Empty strings will be omitted.